@@ -2,7 +2,6 @@ package client
 
 import (
 	"bufio"
-	"context"
 	"errors"
 	"fmt"
 	"io"
@@ -91,7 +90,7 @@ func saveState(args []string, system bool, userName string, noUpdateBootMenu, sa
 	}
 	defer client.Close()
 
-	ctx, cancel := context.WithTimeout(client.Ctx, config.DefaultClientTimeout)
+	ctx, cancel, reset := contextWithResettableTimeout(client.Ctx, config.DefaultClientTimeout)
 	defer cancel()
 
 	if system {
@@ -101,13 +100,14 @@ func saveState(args []string, system bool, userName string, noUpdateBootMenu, sa
 			Autosave:       saveAuto,
 		})
 
-		if err = checkConn(err); err != nil {
+		if err = checkConn(err, reset); err != nil {
 			return err
 		}
 
 		for {
 			r, err := stream.Recv()
 			if err == streamlogger.ErrLogMsg {
+				reset <- struct{}{}
 				continue
 			}
 			if err == io.EOF {
@@ -130,13 +130,14 @@ func saveState(args []string, system bool, userName string, noUpdateBootMenu, sa
 
 		stream, err := client.SaveUserState(ctx, &zsys.SaveUserStateRequest{UserName: userName, StateName: stateName})
 
-		if err = checkConn(err); err != nil {
+		if err = checkConn(err, reset); err != nil {
 			return err
 		}
 
 		for {
 			r, err := stream.Recv()
 			if err == streamlogger.ErrLogMsg {
+				reset <- struct{}{}
 				continue
 			}
 			if err == io.EOF {
@@ -226,7 +227,7 @@ func removeState(args []string) (err error) {
 }
 
 func removeStateGRPC(client *zsys.ZsysLogClient, force, dryrun, system bool, userName, stateName string) error {
-	ctx, cancel := context.WithTimeout(client.Ctx, config.DefaultClientTimeout)
+	ctx, cancel, reset := contextWithResettableTimeout(client.Ctx, config.DefaultClientTimeout)
 	defer cancel()
 
 	var err error
@@ -238,13 +239,14 @@ func removeStateGRPC(client *zsys.ZsysLogClient, force, dryrun, system bool, use
 			Dryrun:    dryrun,
 		})
 
-		if err = checkConn(err); err != nil {
+		if err = checkConn(err, reset); err != nil {
 			return err
 		}
 
 		for {
 			_, err = stream.Recv()
 			if err == streamlogger.ErrLogMsg {
+				reset <- struct{}{}
 				continue
 			}
 			if err != nil {
@@ -263,13 +265,14 @@ func removeStateGRPC(client *zsys.ZsysLogClient, force, dryrun, system bool, use
 			Dryrun:    dryrun,
 		})
 
-		if err = checkConn(err); err != nil {
+		if err = checkConn(err, reset); err != nil {
 			return err
 		}
 
 		for {
 			_, err = stream.Recv()
 			if err == streamlogger.ErrLogMsg {
+				reset <- struct{}{}
 				continue
 			}
 			if err != nil {
