@@ -8,11 +8,15 @@ const (
 	// NoModifiedBoot is the message to print when the current boot has no dataset modifications
 	NoModifiedBoot = "zsys-meta:no-modified-boot"
 
-	// DefaultSocket path.
-	DefaultSocket = "/run/zsysd.sock"
+	// defaultSocket path.
+	defaultSocket = "/run/zsysd.sock"
+	// socketEnv overrides default socket via environment variable
+	socketEnv = "ZSYSD_SOCKET"
 
-	// DefaultClientTimeout for client requests
-	DefaultClientTimeout = 120 * time.Second
+	// DefaultClientWaitOnServiceReady for client on waiting on service to start
+	DefaultClientWaitOnServiceReady = time.Minute
+	// DefaultClientTimeout for client requests between 2 pings
+	DefaultClientTimeout = 30 * time.Second
 
 	// DefaultServerIdleTimeout is the default time without a request before the server exits
 	DefaultServerIdleTimeout = time.Minute
