@@ -125,13 +125,16 @@ func (d *Dataset) refreshProperties(ctx context.Context) error {
 			log.Warningf(ctx, i18n.G("can't read bootfsdataset property, ignoring: ")+config.ErrorFormat, err)
 		}
 		// TOREMOVE: transition from 19.10 installation without zsys to 20.04 after installing zsys
-		if strings.Contains(d.Name, "/USERDATA/") && bootfsDatasets == "" {
-			bootfsDatasets, srcBootfsDatasets, _ = getUserPropertyFromSys(ctx, "org.zsys:bootfs-datasets", d.dZFS)
-			if bootfsDatasets != "" {
-				if err := d.dZFS.SetUserProperty(libzfs.BootfsDatasetsProp, bootfsDatasets); err != nil {
+		if strings.Contains(d.Name, "/"+UserdataPrefix+"/") && bootfsDatasets == "" {
+			oldBootfsDatasets, oldSrcBootfsDatasets, _ := getUserPropertyFromSys(ctx, "org.zsys:bootfs-datasets", d.dZFS)
+			if oldBootfsDatasets != "" {
+				if err := d.dZFS.SetUserProperty(libzfs.BootfsDatasetsProp, oldBootfsDatasets); err != nil {
 					log.Warningf(ctx, i18n.G("can't transition bootfsdataset property, ignoring: ")+config.ErrorFormat, err)
 				}
 			}
+			if oldSrcBootfsDatasets != "" {
+				srcBootfsDatasets = oldBootfsDatasets
+			}
 		}
 	}
 	sources.BootfsDatasets = srcBootfsDatasets
@@ -299,6 +302,20 @@ func (d Dataset) HasSnapshotInHierarchy() bool {
 	return false
 }
 
+// IsUserDataset returns if this filesystem dataset is or has been a userdataset, even if unlinked to any filesystem dataset
+// Note that it doesn’t take into account if the dataset is a clone of a userdataset.
+// Snapshots will always return an error, check the filesystem dataset first.
+func (d Dataset) IsUserDataset() (bool, error) {
+	if !strings.Contains(d.Name, "/"+UserdataPrefix+"/") {
+		return false, nil
+	}
+
+	if d.IsSnapshot {
+		return false, fmt.Errorf(i18n.G("IsUserDataset called on snapshot %q."), d.Name)
+	}
+	return d.sources.BootfsDatasets != "", nil
+}
+
 // checkNoClone checks that the hierarchy has no clone.
 func (d *Dataset) checkNoClone() error {
 	// TODO: this reopens the pool entirely, so can be a little bit slow. Could be reimplemented ourselves.
@@ -359,6 +376,23 @@ func (d *Dataset) setProperty(name, value, source string) (err error) {
 		}
 
 		err = d.dZFS.SetUserProperty(up, v)
+		if err != nil {
+			return err
+		}
+
+		// TODO: remove once we mock rather time.Now() for mock tests
+		// Reload last used property from backend (as we can have set it to magic time)
+		if name == libzfs.LastUsedProp {
+			if prop, errRead := d.dZFS.GetUserProperty(up); errRead == nil {
+				value = prop.Value
+			}
+			if value == "" {
+				value = "0"
+			}
+			if _, err := strconv.Atoi(value); err != nil {
+				return fmt.Errorf(i18n.G("%q property isn't an int: ")+config.ErrorFormat, libzfs.LastUsedProp, err)
+			}
+		}
 	}
 
 	if err != nil {
