@@ -12,6 +12,11 @@ import (
 	"github.com/ubuntu/zsys/internal/zfs/libzfs"
 )
 
+const (
+	// UserdataPrefix is the part of the path of the dataset that contains user data
+	UserdataPrefix = "USERDATA"
+)
+
 // Dataset is the abstraction of a physical dataset and exposes only properties that must are accessible by the user.
 type Dataset struct {
 	// Name of the dataset.
@@ -832,7 +837,7 @@ func (t *Transaction) SetProperty(name, value, datasetName string, force bool) e
 // A dataset has dependencies if:
 //   - it has a subdataset (has child)
 //   - it has a snapshot (so has child as well)
-//   - there is a clone depending on it (clone depending on snapshot on this dataset,
+//   - there is a clone depending on it or any of its child (clone depending on snapshot on this dataset,
 //     so meaning that this dataset has a snapshot, so has child as well)
 func (nt *NoTransaction) Dependencies(d Dataset) []*Dataset {
 	ctx := nt.ctx
